@@ -263,6 +263,13 @@ class R2Conv(EquivariantModule):
         else:
             raise ValueError('Basis Expansion algorithm "%s" not recognized' % basisexpansion)
         
+        if self.basisexpansion.dimension() == 0:
+            raise ValueError('''
+                The basis for the steerable filter is empty!
+                Tune the `frequencies_cutoff`, `kernel_size`, `rings`, `sigma` or `basis_filter` parameters to allow
+                for a larger basis.
+            ''')
+
         self.weights = Parameter(torch.zeros(self.basisexpansion.dimension()), requires_grad=True)
         self.register_buffer("filter", torch.zeros(out_type.size, in_type.size, kernel_size, kernel_size))
         
@@ -293,15 +300,15 @@ class R2Conv(EquivariantModule):
             the expanded filter and bias
 
         """
-        filter = self.basisexpansion(self.weights)
-        filter = filter.reshape(filter.shape[0], filter.shape[1], self.kernel_size, self.kernel_size)
+        _filter = self.basisexpansion(self.weights)
+        _filter = _filter.reshape(_filter.shape[0], _filter.shape[1], self.kernel_size, self.kernel_size)
         
         if self.bias is None:
-            bias = None
+            _bias = None
         else:
-            bias = self.bias_expansion @ self.bias
+            _bias = self.bias_expansion @ self.bias
             
-        return filter, bias
+        return _filter, _bias
 
     def forward(self, input: GeometricTensor):
         r"""
@@ -318,29 +325,29 @@ class R2Conv(EquivariantModule):
         assert input.type == self.in_type
 
         if not self.training:
-            filter = self.filter
-            bias = self.expanded_bias
+            _filter = self.filter
+            _bias = self.expanded_bias
         else:
             # retrieve the filter and the bias
-            filter, bias = self.expand_parameters()
+            _filter, _bias = self.expand_parameters()
         
         # use it for convolution and return the result
         
         if self.padding_mode == 'zeros':
-            output = conv2d(input.tensor, filter,
+            output = conv2d(input.tensor, _filter,
                             stride=self.stride,
                             padding=self.padding,
                             dilation=self.dilation,
                             groups=self.groups,
-                            bias=bias)
+                            bias=_bias)
         else:
             output = conv2d(pad(input.tensor, self._reversed_padding_repeated_twice, self.padding_mode),
-                            filter,
+                            _filter,
                             stride=self.stride,
-                            padding=self.padding,
                             dilation=self.dilation,
+                            padding=(0,0),
                             groups=self.groups,
-                            bias=bias)
+                            bias=_bias)
 
         return GeometricTensor(output, self.out_type)
     
@@ -376,11 +383,11 @@ class R2Conv(EquivariantModule):
         elif self.training:
             # avoid re-computation of the filter and the bias on multiple consecutive calls of `.eval()`
             
-            filter, bias = self.expand_parameters()
+            _filter, _bias = self.expand_parameters()
     
-            self.register_buffer("filter", filter)
-            if bias is not None:
-                self.register_buffer("expanded_bias", bias)
+            self.register_buffer("filter", _filter)
+            if _bias is not None:
+                self.register_buffer("expanded_bias", _bias)
             else:
                 self.expanded_bias = None
 
@@ -498,8 +505,25 @@ class R2Conv(EquivariantModule):
         # set to eval mode so the filter and the bias are updated with the current
         # values of the weights
         self.eval()
-        filter = self.filter
-        bias = self.expanded_bias
+        _filter = self.filter
+        _bias = self.expanded_bias
+
+        if self.padding_mode not in ['zeros']:
+            x, y = torch.__version__.split('.')[:2]
+            if int(x) < 1 or int(y) < 5:
+                if self.padding_mode == 'circular':
+                    raise ImportError(
+                        "'{}' padding mode had some issues in old `torch` versions. Therefore, we only support conversion from version 1.5 but only version {} is installed.".format(
+                            self.padding_mode, torch.__version__
+                        )
+                    )
+
+                else:
+                    raise ImportError(
+                        "`torch` supports '{}' padding mode only from version 1.5 but only version {} is installed.".format(
+                            self.padding_mode, torch.__version__
+                        )
+                    )
 
         # build the PyTorch Conv2d module
         has_bias = self.bias is not None
@@ -507,15 +531,16 @@ class R2Conv(EquivariantModule):
                                self.out_type.size,
                                self.kernel_size,
                                padding=self.padding,
+                               padding_mode=self.padding_mode,
                                stride=self.stride,
                                dilation=self.dilation,
                                groups=self.groups,
                                bias=has_bias)
 
         # set the filter and the bias
-        conv.weight.data = filter.data
+        conv.weight.data = _filter.data
         if has_bias:
-            conv.bias.data = bias.data
+            conv.bias.data = _bias.data
         
         return conv
 
@@ -571,10 +596,10 @@ def bandlimiting_filter(frequency_cutoff: Union[float, Callable[[float], float]]
     if isinstance(frequency_cutoff, float):
         frequency_cutoff = lambda r, fco=frequency_cutoff: r * frequency_cutoff
     
-    def filter(attributes: dict) -> bool:
+    def bl_filter(attributes: dict) -> bool:
         return math.fabs(attributes["frequency"]) <= frequency_cutoff(attributes["radius"])
     
-    return filter
+    return bl_filter
 
 
 def get_grid_coords(kernel_size: int, dilation: int = 1):
@@ -684,11 +709,11 @@ def _manual_fco3(max_radius: float) -> Callable[[float], float]:
 
     """
     
-    def filter(r: float) -> float:
+    def bl_filter(r: float) -> float:
         max_freq = 0 if r == 0. else 1 if r == max_radius else 2
         return max_freq
     
-    return filter
+    return bl_filter
 
 
 def _manual_fco2(max_radius: float) -> Callable[[float], float]:
@@ -705,11 +730,11 @@ def _manual_fco2(max_radius: float) -> Callable[[float], float]:
 
     """
     
-    def filter(r: float) -> float:
+    def bl_filter(r: float) -> float:
         max_freq = 0 if r == 0. else min(2 * r, 1 if r == max_radius else 2 * r - (r + 1) % 2)
         return max_freq
     
-    return filter
+    return bl_filter
 
 
 def _manual_fco1(max_radius: float) -> Callable[[float], float]:
@@ -726,11 +751,11 @@ def _manual_fco1(max_radius: float) -> Callable[[float], float]:
 
     """
     
-    def filter(r: float) -> float:
+    def bl_filter(r: float) -> float:
         max_freq = 0 if r == 0. else min(2 * r, 2 if r == max_radius else 2 * r - (r + 1) % 2)
         return max_freq
     
-    return filter
+    return bl_filter
 
 
 
